IF OBJECT_ID('[DockerRepositories_Extended]') IS NOT NULL DROP VIEW [DockerRepositories_Extended]
GO

CREATE VIEW [DockerRepositories_Extended]
AS

SELECT DR.*,
       DI.[Download_Count],
       DI.[Image_Count],
       DI.[Updated_Date],
       DI.[Cached_Indicator],
	   VULN.[Vulnerabilities_Severity_Code],
	   VULN.[Vulnerabilities_Unassessed_Indicator],
	   [Vulnerabilities_Count] = COALESCE(VULN.[Vulnerabilities_Count],0),
	   [AssessedVulnerabilities_Count] = COALESCE(AVULN.[Vulnerabilities_Count],0),
	   [HelmChartCount] = COALESCE(HC.[HelmChartCount],0)
  FROM [DockerRepositories] DR
       LEFT JOIN (SELECT [DockerRepository_Id],
                         [Updated_Date] = MAX([Published_Date]),
                         [Download_Count] = SUM([Download_Count]),
                         [Image_Count] = COUNT(*),
                         [Cached_Indicator] = CASE WHEN COUNT(CASE WHEN [Cached_Indicator] = 'N' THEN 1 ELSE NULL END) = 0 THEN 'Y' ELSE 'N' END
                    FROM [DockerImages]
                   GROUP BY [DockerRepository_Id]) DI
              ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
       LEFT JOIN (SELECT DI.[DockerRepository_Id], 
	                     [Vulnerabilities_Severity_Code] = SUBSTRING('EWCN', MAX(CHARINDEX(A.[Severity_Code],'EWCN')), 1),
						 [Vulnerabilities_Unassessed_Indicator] = CASE WHEN COUNT(CASE WHEN A.[Severity_Code] IS NULL THEN 1 ELSE NULL END) = 0 THEN 'N' ELSE 'Y' END,
	                     [Vulnerabilities_Count] = COUNT(*)
                    FROM [Vulnerabilities] V
                         LEFT JOIN [AssessmentTypes] A
                                ON A.[AssessmentType_Id] = V.[AssessmentType_Id]
                              AND (A.[Expiration_Days] IS NULL OR DATEADD(day, A.[Expiration_Days], V.[Assessment_Date]) > GETUTCDATE())
                       LEFT JOIN [FeedVulnerabilitySources] FVS ON FVS.[VulnerabilitySource_Id] = V.[VulnerabilitySource_Id]
                       INNER JOIN [DockerBlobs] DB ON DB.[Blob_Digest] = V.[Blob_Digest]
                       INNER JOIN [DockerImageLayers] DIL ON DIL.[DockerBlob_Id] = DB.[DockerBlob_Id]
                       INNER JOIN [DockerImages] DI ON DI.[DockerImage_Id] = DIL.[DockerImage_Id]
					   INNER JOIN [DockerRepositories] IDR ON IDR.[DockerRepository_Id] = DI.[DockerRepository_Id]
					WHERE V.[Feed_Id] = IDR.[Feed_Id] OR FVS.[Feed_Id] = IDR.[Feed_Id]
                  GROUP BY DI.[DockerRepository_Id]) VULN
              ON DI.[DockerRepository_Id] = VULN.[DockerRepository_Id]
       LEFT JOIN (SELECT DI.[DockerRepository_Id], 
	                     [Vulnerabilities_Severity_Code] = SUBSTRING('EWCN', MAX(CHARINDEX(A.[Severity_Code],'EWCN')), 1),
						 [Vulnerabilities_Unassessed_Indicator] = CASE WHEN COUNT(CASE WHEN A.[Severity_Code] IS NULL THEN 1 ELSE NULL END) = 0 THEN 'N' ELSE 'Y' END,
	                     [Vulnerabilities_Count] = COUNT(*)
                    FROM [Vulnerabilities] V
                         LEFT JOIN [AssessmentTypes] A
                                ON A.[AssessmentType_Id] = V.[AssessmentType_Id]
                              AND (A.[Expiration_Days] IS NULL OR DATEADD(day, A.[Expiration_Days], V.[Assessment_Date]) > GETUTCDATE())
                       LEFT JOIN [FeedVulnerabilitySources] FVS ON FVS.[VulnerabilitySource_Id] = V.[VulnerabilitySource_Id]
                       INNER JOIN [DockerBlobs] DB ON DB.[Blob_Digest] = V.[Blob_Digest]
                       INNER JOIN [DockerImageLayers] DIL ON DIL.[DockerBlob_Id] = DB.[DockerBlob_Id]
                       INNER JOIN [DockerImages] DI ON DI.[DockerImage_Id] = DIL.[DockerImage_Id]
					   INNER JOIN [DockerRepositories] IDR ON IDR.[DockerRepository_Id] = DI.[DockerRepository_Id]
					WHERE (V.[Feed_Id] = IDR.[Feed_Id] OR FVS.[Feed_Id] = IDR.[Feed_Id])  AND v.AssessmentType_Id IS NOT NULL
                  GROUP BY DI.[DockerRepository_Id]) AVULN
              ON DI.[DockerRepository_Id] = AVULN.[DockerRepository_Id]
			LEFT JOIN (SELECT HCDI.[DockerRepository_Id], COUNT([Chart_Name]) as [HelmChartCount]
							FROM [HelmChartDockerImages] HCDI
							GROUP BY HCDI.[DockerRepository_Id]
						) HC
				ON HC.[DockerRepository_Id] = DR.[DockerRepository_Id]
GO