IF OBJECT_ID('[NuGetPackageVersionsV2_Extended]') IS NOT NULL DROP VIEW [NuGetPackageVersionsV2_Extended]
GO

CREATE VIEW [NuGetPackageVersionsV2_Extended]
AS
	SELECT NP2.[NuGetPackageV2_Id],
		   NP2.[Feed_Id],
	       NP2.[Package_Id],
		   NPV2.[Version_Text],
		   NPV2.[FullVersion_Text],
		   NPV2.[Published_Date],
		   NPV2.[Package_Size],
		   NPV2.[Download_Count],
		   NPV2.[PackageHash_SHA1_Bytes],
		   NPV2.[PackageHash_SHA512_Bytes],
		   NPV2.[TargetFrameworks_Text],
		   NPV2.[Nuspec_Bytes],
		   NPV2.[Symbols_Indicator],
		   NPV2.[Source_Indicator],
		   NPV2.[Cached_Indicator],
		   NPV2.[Listed_Indicator],
		   NPV2.[LastDownloaded_Date],
		   [LatestAbsoluteVersion_Indicator] = CASE WHEN NP2.[LatestVersion_Text] = NPV2.[Version_Text] THEN 'Y' ELSE 'N' END,
		   [LatestStableVersion_Indicator] = CASE WHEN NP2.[LatestStableVersion_Text] = NPV2.[Version_Text] THEN 'Y' ELSE 'N' END,
		   _D.[LastConsumed_Date],
		   [ActiveFeedConsumer_Indicator] = COALESCE(_D.[ActiveFeedConsumer_Indicator], 'N')
	  FROM [NuGetPackageVersionsV2] NPV2
	       INNER JOIN [NuGetPackagesV2] NP2
		           ON NP2.[NuGetPackageV2_Id] = NPV2.[NuGetPackageV2_Id]
		    LEFT JOIN (SELECT PD.[Feed_Id],
							  [Group_Name],
	                          PD.[Package_Name],
							  PD.[Version_Text],
	                          [LastConsumed_Date] = MAX(PD.[Created_Date]),
	                          [ActiveFeedConsumer_Indicator] = CASE WHEN MAX(PD.[Dependent_Feed_Id]) IS NULL THEN 'N' ELSE 'Y' END
                         FROM [PackageDependents] PD
                        GROUP BY PD.[Feed_Id], PD.[Group_Name], PD.[Package_Name], PD.[Version_Text]) _D
				   ON _D.[Feed_Id] = NP2.[Feed_Id]
				  AND _D.[Group_Name] IS NULL
				  AND _D.[Package_Name] = NP2.[Package_Id]
				  AND _D.[Version_Text] = NPV2.[Version_Text]
GO