EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'PackageContainerScanners_CreateOrUpdateScanner',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'PackageContainerScanner_Id',
    /* Description_Text        */ 'Creates a new package/container scanner or updates an existing one.'
GO

IF OBJECT_ID('[PackageContainerScanners_CreateOrUpdateScanner]') IS NOT NULL DROP PROCEDURE [PackageContainerScanners_CreateOrUpdateScanner]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [PackageContainerScanners_CreateOrUpdateScanner]
(
	@Configuration_Xml XML,
	@PackageContainerScanner_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [PackageContainerScanners] WITH (UPDLOCK) WHERE [PackageContainerScanner_Id] = @PackageContainerScanner_Id)
	BEGIN

		UPDATE [PackageContainerScanners]
		   SET [Configuration_Xml] = @Configuration_Xml
		 WHERE [PackageContainerScanner_Id] = @PackageContainerScanner_Id

	END
	ELSE
	BEGIN

		INSERT INTO [PackageContainerScanners]
		(
			[Configuration_Xml]
		)
		VALUES
		(
			@Configuration_Xml
		)

		SET @PackageContainerScanner_Id = SCOPE_IDENTITY()

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [PackageContainerScanners_CreateOrUpdateScanner] TO [ProGetUser_Role]
GO